/*
 * BufferSelectionOptionPane.java
 * Copyright (c) 2000 Andre Kaplan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */


import javax.swing.JCheckBox;
import javax.swing.JTextField;

import org.gjt.sp.jedit.AbstractOptionPane;
import org.gjt.sp.jedit.jEdit;
import org.gjt.sp.util.Log;


/**
 * Option pane for BufferSelector
 * @author  Andre Kaplan
 * @version $Id: BufferSelectorOptionPane.java,v 1.6 2000/12/31 16:19:43 akaplan Exp $
**/
public class BufferSelectorOptionPane extends AbstractOptionPane
{
    private JCheckBox defaultEnabled;
    private JCheckBox useToolbar;
    private JTextField minWidth;
    private JTextField maxWidth;
    private JTextField fontSize;


    public BufferSelectorOptionPane() {
        super(jEdit.getProperty("buffer-selector.label", "Buffer Selector"));
    }


    public void _init() {
        this.defaultEnabled = new JCheckBox(
            jEdit.getProperty("options.buffer-selector.default-enabled"),
            jEdit.getBooleanProperty("buffer-selector.default-enabled", false)
        );
        addComponent(this.defaultEnabled);

        this.useToolbar = new JCheckBox(
            jEdit.getProperty("options.buffer-selector.use-toolbar"),
            jEdit.getBooleanProperty("buffer-selector.use-toolbar", false)
        );
        addComponent(this.useToolbar);

        this.minWidth = new JTextField(
            jEdit.getProperty("buffer-selector.min-width"), 3);
        addComponent(jEdit.getProperty("options.buffer-selector.min-width"),
            this.minWidth);

        this.maxWidth = new JTextField(
            jEdit.getProperty("buffer-selector.max-width"), 3);
        addComponent(jEdit.getProperty("options.buffer-selector.max-width"),
            this.maxWidth);

        this.fontSize = new JTextField(
            jEdit.getProperty("buffer-selector.font-size"), 2);
        addComponent(jEdit.getProperty("options.buffer-selector.font-size"),
            this.fontSize);
    }


    public void _save() {
        jEdit.setBooleanProperty("buffer-selector.default-enabled",
            this.defaultEnabled.isSelected());

        jEdit.setBooleanProperty("buffer-selector.use-toolbar",
            this.useToolbar.isSelected());

        int min = 0;
        String[] minWidths = {
            this.minWidth.getText(),
            jEdit.getProperty("buffer-selector.min-width")
        };
        for (int i = 0; i < minWidths.length; i++) {
            try {
                min = Integer.parseInt(minWidths[i]);
                if (min > 0) {
                    jEdit.setProperty("buffer-selector.min-width",minWidths[i]);
                    break;
                }
            } catch (NumberFormatException nfe) {
                Log.log(Log.ERROR, this, nfe);
            }
        }

        int max = 0;
        String[] maxWidths = {
            this.maxWidth.getText(),
            jEdit.getProperty("buffer-selector.max-width")
        };
        for (int i = 0; i < maxWidths.length; i++) {
            try {
                max = Integer.parseInt(maxWidths[i]);
                if (max > 0) {
                    jEdit.setProperty("buffer-selector.max-width",maxWidths[i]);
                    break;
                }
            } catch (NumberFormatException nfe) {
                Log.log(Log.ERROR, this, nfe);
            }
        }

        if (min <= 0) {
            min = 100;
            jEdit.setProperty("buffer-selector.min-width", "" + min);
        }
        if (max <= 0) {
            max = 150;
            jEdit.setProperty("buffer-selector.max-width", "" + max);
        }
        if (max < min) {
            jEdit.setProperty("buffer-selector.max-width", "" + min);
        }

        try {
            int s = Integer.parseInt(this.fontSize.getText());
            if (s > 0) {
                jEdit.setProperty("buffer-selector.font-size",
                    this.fontSize.getText());
            }
        } catch (NumberFormatException nfe) {
            Log.log(Log.ERROR, this, nfe);
        }
    }
}
